@@ -6,7 +6,8 @@ from pymatgen.io.ase import AseAtomsAdaptor
 from pymatgen.core.periodic_table import Element
 from pymatgen.analysis.local_env import CrystalNN
 from ase.data import atomic_numbers, chemical_symbols
-from typing import Dict
+from typing import Dict, List
+from ase import Atoms
 import numpy as np
 from matplotlib.colors import Normalize
 import matplotlib.pyplot as plt
@@ -45,33 +46,18 @@ class IonicSurfaceMatcher:
         self.sub_part = self.interface._orthogonal_film_structure
         self.grid_density_x = grid_density_x
         self.grid_density_y = grid_density_y
-        self.opt_xy_shift = np.zeros(3)
-        self.opt_z_shift = np.zeros(3)
+        self.opt_xy_shift = np.zeros(2)
 
         self.shifts, self.X, self.Y = self._generate_shifts()
         self.z_PES_data = None
 
     def get_optmized_structure(self):
-        opt_shift = self.opt_xy_shift + self.opt_z_shift
-        self.interface.shift_film(
-            shift=opt_shift, fractional=True, inplace=True
+        opt_shift = self.opt_xy_shift
+
+        self.interface.shift_film_inplane(
+            x_shift=opt_shift[0], y_shift=opt_shift[1], fractional=True
         )
 
-    # def _get_charges_and_radii(self):
-    #     sub = self.interface.substrate.conventional_bulk_structure
-    #     film = self.interface.film.conventional_bulk_structure
-    #     sub_oxidation_state = sub.composition.oxi_state_guesses()[0]
-    #     film_oxidation_state = film.composition.oxi_state_guesses()[0]
-
-    #     sub_oxidation_state.update(film_oxidation_state)
-
-    #     radii = {
-    #         element: Element(element).ionic_radii[charge]
-    #         for element, charge in sub_oxidation_state.items()
-    #     }
-
-    #     return sub_oxidation_state, radii
-
     def _get_charges(self):
         sub = self.interface.substrate.bulk_structure
         film = self.interface.film.bulk_structure
@@ -223,104 +209,37 @@ class IonicSurfaceMatcher:
         grid_y = np.linspace(0, 1, self.grid_density_y)
         X, Y = np.meshgrid(grid_x, grid_y)
 
-        shifts = np.c_[X.ravel(), Y.ravel(), np.zeros(X.shape).ravel()]
+        shifts = np.c_[X.ravel(), Y.ravel()]
 
         return shifts, X, Y
 
-    def _get_shifted_atoms_old(self, shifts):
-
-        atoms = [
-            AseAtomsAdaptor().get_atoms(self.sub_part),
-            AseAtomsAdaptor().get_atoms(self.film_part),
-        ]
-
-        for shift in shifts:
-            shifted_atoms = self.interface.shift_film(
-                shift, fractional=True, inplace=False, return_atoms=True
-            )
-            atoms.append(shifted_atoms)
-
-        return atoms
-
-    def _get_shifted_atoms(self, shifts):
+    def _get_shifted_atoms(self, shifts: np.ndarray) -> List[Atoms]:
         atoms = []
-        z_atoms = []
-
-        z_shift = np.array([0, 0, 10]) / np.linalg.norm(self.matrix[-1])
 
         for shift in shifts:
-            shifted_atoms = self.interface.shift_film(
-                shift + self.opt_z_shift,
-                fractional=True,
-                inplace=False,
-                return_atoms=True,
+            # Shift in-plane
+            self.interface.shift_film_inplane(
+                x_shift=shift[0], y_shift=shift[1], fractional=True
             )
+
+            # Get inplane shifted atoms
+            shifted_atoms = self.interface.get_interface(
+                orthogonal=True, return_atoms=True
+            )
+
+            # Add the is_film property
             shifted_atoms.set_array(
                 "is_film",
                 self.interface._orthogonal_structure.site_properties[
                     "is_film"
                 ],
             )
-            z_shifted_atoms = self.interface.shift_film(
-                shift + z_shift,
-                fractional=True,
-                inplace=False,
-                return_atoms=True,
+
+            self.interface.shift_film_inplane(
+                x_shift=-shift[0], y_shift=-shift[1], fractional=True
             )
-            z_shifted_atoms.set_array(
-                "is_film",
-                self.interface._orthogonal_structure.site_properties[
-                    "is_film"
-                ],
-            )
-            atoms.append(shifted_atoms)
-            z_atoms.append(z_shifted_atoms)
 
-        return atoms, z_atoms
-
-    def _get_shifted_atoms_z(self, shifts):
-        z_shift = np.array([0, 0, 10]) / np.linalg.norm(self.matrix[-1])
-        atoms = [
-            self.interface.shift_film(
-                z_shift + self.opt_xy_shift,
-                fractional=True,
-                inplace=False,
-                return_atoms=True,
-            )
-        ]
-        atoms[0].set_array(
-            "is_film",
-            self.interface._orthogonal_structure.site_properties["is_film"],
-        )
-
-        for shift in shifts:
-            shifted_atoms = self.interface.shift_film(
-                shift + self.opt_xy_shift,
-                fractional=True,
-                inplace=False,
-                return_atoms=True,
-            )
-            shifted_atoms.set_array(
-                "is_film",
-                self.interface._orthogonal_structure.site_properties[
-                    "is_film"
-                ],
-            )
-            atoms.append(shifted_atoms)
-
-        return atoms
-
-    def _get_shifted_strucs(self, shifts):
-
-        atoms = [
-            self.sub_part,
-            self.film_part,
-        ]
-
-        for shift in shifts:
-            shifted_atoms = self.interface.shift_film(
-                shift, fractional=True, inplace=False, return_atoms=False
-            )
+            # Add atoms to the list
             atoms.append(shifted_atoms)
 
         return atoms
@@ -330,21 +249,24 @@ class IonicSurfaceMatcher:
             atoms=atoms_list,
             cutoff=self.cutoff,
             charge_dict=self.charge_dict,
-            # radius_dict=self.radius_dict,
             ns_dict=self.ns_dict,
         )
 
         return inputs
 
-    def _calculate_coulomb(self, inputs):
-        ewald = EnergyEwald(alpha=self.alpha, k_max=self.k_max)
-        coulomb_energy = ewald.forward(inputs)
+    def _calculate_coulomb(self, inputs, z_shift=False):
+        ewald = EnergyEwald(
+            alpha=self.alpha, k_max=self.k_max, cutoff=self.cutoff
+        )
+        coulomb_energy = ewald.forward(inputs, z_shift)
 
         return coulomb_energy
 
-    def _calculate_born(self, inputs):
+    def _calculate_born(self, inputs, z_shift=False):
         born = EnergyBorn(cutoff=self.cutoff)
-        born_energy = born.forward(inputs, r0_dict=self.r0_dict)
+        born_energy = born.forward(
+            inputs, z_shift=z_shift, r0_dict=self.r0_dict
+        )
 
         return born_energy
 
@@ -429,13 +351,12 @@ class IonicSurfaceMatcher:
         show_max: bool = False,
     ) -> float:
         shifts = self.shifts
-        atoms_list, z_atoms_list = self._get_shifted_atoms(shifts)
-
+        atoms_list = self._get_shifted_atoms(shifts)
         inputs = self._generate_inputs(atoms_list)
+
         if self.z_PES_data is None:
-            z_inputs = self._generate_inputs(z_atoms_list)
-            z_coulomb_energy = self._calculate_coulomb(z_inputs)
-            z_born_energy = self._calculate_born(z_inputs)
+            z_coulomb_energy = self._calculate_coulomb(inputs, z_shift=True)
+            z_born_energy = self._calculate_born(inputs, z_shift=True)
             z_interface_coulomb_energy = z_coulomb_energy.reshape(self.X.shape)
             z_interface_born_energy = z_born_energy.reshape(self.X.shape)
             self.z_PES_data = [
@@ -446,8 +367,8 @@ class IonicSurfaceMatcher:
             z_interface_coulomb_energy = self.z_PES_data[0]
             z_interface_born_energy = self.z_PES_data[1]
 
-        coulomb_energy = self._calculate_coulomb(inputs)
-        born_energy = self._calculate_born(inputs)
+        coulomb_energy = self._calculate_coulomb(inputs, z_shift=False)
+        born_energy = self._calculate_born(inputs, z_shift=False)
 
         interface_coulomb_energy = coulomb_energy.reshape(self.X.shape)
         interface_born_energy = born_energy.reshape(self.X.shape)
@@ -564,131 +485,10 @@ class IonicSurfaceMatcher:
                 zorder=10,
             )
 
-        self.opt_xy_shift = opt_shift
+        self.opt_xy_shift = opt_shift[:2]
 
         fig.tight_layout()
         fig.savefig(output, bbox_inches="tight")
         plt.close(fig)
 
         return max_Z
-
-    def run_z_shifts_old(
-        self,
-        interfacial_distances: np.ndarray = np.linspace(2.0, 4.0, 101),
-        fontsize: int = 12,
-        output: str = "z_shift.png",
-        shift: bool = True,
-    ) -> float:
-        z_shifts = interfacial_distances - self.d_interface
-        shifts = np.c_[
-            np.zeros((len(z_shifts), 2)), z_shifts
-        ] / np.linalg.norm(self.matrix[-1])
-        inputs = self._generate_inputs(shifts)
-
-        coulomb_energy = self._calculate_coulomb(inputs)
-        born_energy = self._calculate_born(inputs)
-
-        sub_coulomb_energy = coulomb_energy[0]
-        film_coulomb_energy = coulomb_energy[1]
-        interface_coulomb_energy = coulomb_energy[2:]
-
-        sub_born_energy = born_energy[0]
-        film_born_energy = born_energy[1]
-        interface_born_energy = born_energy[2:]
-
-        # pmg_coulomb_adh_energy = (
-        #     sub_pmg_coulomb_energy + film_pmg_coulomb_energy
-        # ) - interface_pmg_coulomb_energy
-        coulomb_adh_energy = (
-            sub_coulomb_energy + film_coulomb_energy
-        ) - interface_coulomb_energy
-        born_adh_energy = (
-            sub_born_energy + film_born_energy
-        ) - interface_born_energy
-
-        both_adh_energy = born_adh_energy + coulomb_adh_energy
-        # both_pmg_adh_energy = born_adh_energy + pmg_coulomb_adh_energy
-
-        new_x = np.linspace(
-            interfacial_distances.min(), interfacial_distances.max(), 500
-        )
-        new_z_shifts = np.linspace(
-            shifts[:, -1].min(), shifts[:, -1].max(), 500
-        )
-        cs = CubicSpline(interfacial_distances, both_adh_energy)
-        new_y = cs(new_x)
-
-        max_ind = np.argmax(new_y)
-        max_x = new_x[max_ind]
-        max_y = new_y[max_ind]
-        max_shift = new_z_shifts[max_ind]
-
-        if shift:
-            self.interface.shift_film(
-                shift=[0, 0, max_shift], fractional=True, inplace=True
-            )
-
-        fig, ax = plt.subplots(figsize=(4, 4), dpi=400)
-        ax.set_xlabel("Interfacial Distance ($\\AA$)", fontsize=fontsize)
-        ax.set_ylabel("$E_{adh}$", fontsize=fontsize)
-        ax.plot(new_x, new_y, color="black")
-        ax.scatter([max_x], [max_y], color="black", marker="o", s=20)
-        ax.set_xlim(interfacial_distances.min(), interfacial_distances.max())
-
-        fig.tight_layout(pad=0.4)
-        fig.savefig(output)
-        plt.close(fig)
-
-        return max_y
-
-    def run_z_shifts(
-        self,
-        interfacial_distances: np.ndarray = np.linspace(2.0, 4.0, 101),
-        fontsize: int = 12,
-        output: str = "z_shift.png",
-        shift: bool = True,
-    ) -> float:
-        z_shifts = interfacial_distances - self.d_interface
-        shifts = np.c_[
-            np.zeros((len(z_shifts), 2)), z_shifts
-        ] / np.linalg.norm(self.matrix[-1])
-        atoms_list = self._get_shifted_atoms_z(shifts)
-        inputs = self._generate_inputs(atoms_list)
-
-        coulomb_energy = self._calculate_coulomb(inputs)
-        born_energy = self._calculate_born(inputs)
-
-        sub_film_coulomb_energy = coulomb_energy[0]
-        interface_coulomb_energy = coulomb_energy[1:]
-
-        sub_film_born_energy = born_energy[0]
-        interface_born_energy = born_energy[1:]
-
-        coulomb_adh_energy = sub_film_coulomb_energy - interface_coulomb_energy
-        born_adh_energy = sub_film_born_energy - interface_born_energy
-
-        both_adh_energy = born_adh_energy + coulomb_adh_energy
-
-        max_ind = np.argmax(both_adh_energy)
-        max_x = interfacial_distances[max_ind]
-        max_y = both_adh_energy[max_ind]
-        max_shift = shifts[max_ind]
-
-        self.opt_z_shift = max_shift
-
-        fig, ax = plt.subplots(figsize=(4, 4), dpi=400)
-        ax.set_xlabel("Interfacial Distance ($\\AA$)", fontsize=fontsize)
-        ax.set_ylabel("$E_{adh}$", fontsize=fontsize)
-        ax.plot(
-            interfacial_distances,
-            both_adh_energy,
-            color="black",
-        )
-        ax.scatter([max_x], [max_y], color="black", marker="o", s=20)
-        ax.set_xlim(interfacial_distances.min(), interfacial_distances.max())
-
-        fig.tight_layout(pad=0.4)
-        fig.savefig(output)
-        plt.close(fig)
-
-        return max_y
